@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2022-05-05 09:27:59
+@LastEditTime: 2022-08-31 10:46:17
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -46,13 +46,10 @@ class GetCrmIntegralHandler(TopBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_taobao_param().source_app_id
-        user_nick = self.get_taobao_param().user_nick
-        if not user_nick:
-            return self.reponse_json_error("error", "请先授权登录")
         app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if app_info:
             access_token = app_info.access_token
-        invoke_result_data = self.get_crm_point_available(user_nick, access_token)
+        invoke_result_data = self.get_crm_point_available(self.get_taobao_param().mix_nick, access_token)
         if invoke_result_data.success == False:
             return self.reponse_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         shop_member_integral = invoke_result_data.data
