@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-@LastEditTime: 2022-07-26 18:57:44
+@LastEditTime: 2022-12-28 16:40:01
 @LastEditors: HuangJianYi
 :description: 基础接口
 """
@@ -71,8 +71,8 @@ class ActCreateHandler(TopBaseHandler):
         if not act_type_entity:
             return self.reponse_json_error("NoActType", "请管理员先配置活动类型信息")
         skin_info = skin_info_model.get_entity("theme_id=%s", params=theme_info.id)
-        if not skin_info:
-            return self.reponse_json_error("NoSkin", "请管理员先上传皮肤信息")
+        # if not skin_info:
+        #     return self.reponse_json_error("NoSkin", "请管理员先上传皮肤信息")
 
         if not act_id:
             #增加默认活动
@@ -134,7 +134,7 @@ class ActCreateHandler(TopBaseHandler):
             machine_info.machine_price = 0
             #SKUid待定
             machine_info.sku_id = 0
-            machine_info.skin_id = skin_info.id
+            machine_info.skin_id = skin_info.id if skin_info else 0
             machine_info.sort_index = 1
             machine_info.is_release = 1
             machine_info.single_lottery_price = 0
