@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2022-05-05 18:04:54
+@LastEditTime: 2023-02-15 17:03:10
 @LastEditors: HuangJianYi
 :description: 订单相关
 """
@@ -87,6 +87,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
         real_name = self.get_param("real_name")
         telephone = self.get_param("telephone")
         adress = self.get_param("adress")
+        user_open_id = self.get_param("user_open_id")
         order_status = int(self.get_param("order_status", -1))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
@@ -136,6 +137,9 @@ class PrizeOrderListHandler(SevenBaseHandler):
         if order_type > 0:
             condition += " AND order_type=%s"
             params.append(order_type)
+        if user_open_id:
+            condition += " AND open_id=%s"
+            params.append(user_open_id)
 
         page_list, total = PrizeOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
@@ -307,6 +311,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
                         data_row["淘宝子订单号"] = prize_roster["order_no"]
                         data_row["小程序订单号"] = prize_order["order_no"]
                         data_row["淘宝名"] = prize_order["user_nick"]
+                        data_row["open_id"] = prize_order["open_id"]
                         data_row["盒子名称"] = prize_roster["machine_name"]
                         data_row["盒子价格"] = str(prize_roster["machine_price"])
                         data_row["奖品名称"] = prize_roster["prize_name"]
@@ -351,7 +356,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
             #奖品订单
             prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, order_by="create_date desc", params=params)
 
-            data_columns = ["淘宝主订单号", "淘宝子订单号", "小程序订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "商家编码", "姓名", "手机号", "省份", "城市", "区县", "街道", "收货地址", "物流单号", "物流公司", "发货时间","下单时间", "订单状态", "奖品价值", "奖品规格", "备注"]
+            data_columns = ["淘宝主订单号", "淘宝子订单号", "小程序订单号", "淘宝名","open_id", "盒子名称", "盒子价格", "奖品名称", "商家编码", "姓名", "手机号", "省份", "城市", "区县", "街道", "收货地址", "物流单号", "物流公司", "发货时间","下单时间", "订单状态", "奖品价值", "奖品规格", "备注"]
 
             data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"
 
@@ -371,6 +376,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
                         data_row.append("\'" + prize_roster["order_no"])
                         data_row.append("\'" + prize_order["order_no"])
                         data_row.append(prize_order["user_nick"])
+                        data_row.append(prize_order["open_id"])
                         data_row.append(prize_roster["machine_name"])
                         data_row.append(str(prize_roster["machine_price"]))
                         data_row.append(prize_roster["prize_name"])
@@ -448,6 +454,7 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
                 data_row["行为编号"] = prize_roster["id"]
                 data_row["淘宝子订单号"] = prize_roster["order_no"]
                 data_row["淘宝名"] = prize_roster["user_nick"]
+                data_row["open_id"] = prize_roster["open_id"]
                 data_row["盒子名称"] = prize_roster["machine_name"]
                 data_row["盒子价格"] = str(prize_roster["machine_price"])
                 data_row["奖品名称"] = prize_roster["prize_name"]
@@ -474,7 +481,7 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
             #奖品订单
             prize_roster_list, total = prize_roster_model.get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
-            data_columns = ["行为编号", "淘宝子订单号", "淘宝名", "盒子名称", "盒子价格", "奖品名称", "奖品价值", "SKU", "获得时间", "状态"]
+            data_columns = ["行为编号", "淘宝子订单号", "淘宝名", "open_id", "盒子名称", "盒子价格", "奖品名称", "奖品价值", "SKU", "获得时间", "状态"]
 
             data_text = ",".join(list(map(lambda x: "\"" + x + "\"", data_columns))) + "\n"
 
@@ -488,6 +495,7 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
                     else:
                         data_row.append("\'" + prize_roster["order_no"])
                     data_row.append(prize_roster["user_nick"])
+                    data_row.append(prize_roster["open_id"])
                     data_row.append(prize_roster["machine_name"])
                     data_row.append(str(prize_roster["machine_price"]))
                     data_row.append(prize_roster["prize_name"])
